| cov_ogk | R Documentation |
The location and scale functions are computed via pointwise M-estimator, and the covariance function is obtained via robust pairwise computation based on Orthogonalized Gnanadesikan-Kettenring (OGK) estimation. Additionally, bivariate Nadaraya-Watson smoothing is applied for smoothed covariance surfaces.
cov_ogk(
X,
type = c("huber", "bisquare", "tdist"),
MM = TRUE,
smooth = TRUE,
grid = NULL,
bw = NULL,
cv = FALSE,
df = 3,
cv_optns = list(bw_cand = NULL, K = 5, ncores = 1)
)
X |
a n x p matrix. It allows NA. |
type |
the option for robust dispersion estimator. "huber", "bisquare", and "tdist" are supported. |
MM |
the option for M-scale estimator in GK identity. If it is FALSE, the same method using |
smooth |
If it is TRUE, bivariate Nadaraya-Watson smoothing is performed using |
grid |
a vector containing the observed timepoints |
bw |
a bandwidth when |
cv |
If it is TRUE, K-fold cross-validation is performed for the bandwidth selection when |
df |
the degrees of freedm when |
cv_optns |
the options of K-fold cross-validation when |
The options of cv_optns:
a vector contains the candidates of bandwidths for bivariate smoothing.
the number of folds for K-fold cross validation.
the number of cores on foreach for parallel computing.
a list contatining as follows:
mean |
the vector containing the robust mean function. |
cov |
a matrix containing robust covariance function. |
bw |
a bandwidth of the bivariate smoothing selected from K-fold cross-validation |
cv.obj |
cv.obj from bandwidth selection |
Park, Y., Kim, H., & Lim, Y. (2022+). Functional principal component analysis for partially observed elliptical process, Under review.
Maronna, R. A., & Zamar, R. H. (2002). Robust estimates of location and dispersion for high-dimensional datasets. Technometrics, 44(4), 307-317.
set.seed(100)
x.list <- sim_delaigle(n = 100,
type = "partial",
out.prop = 0.2,
dist = "normal")
x <- list2matrix(x.list)
cov.obj <- cov_ogk(x,
type = "huber",
bw = 0.1)
mu.ogk.sm <- cov.obj$mean
cov.ogk.sm <- cov.obj$cov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.